@@ -74,11 +74,11 @@ def parse_annos(path_anno_folder):
     pool.join()
     annos_dict = {}
     for anno in res:
-        annos_dict[anno['annoname']] = anno
+        annos_dict[os.path.splitext(anno['annoname'])[0]] = anno
     return annos_dict
 
 
-def check_match(path_1, path_2):
+def is_match(path_1, path_2):
     """
     Check if the file names in the folders match each other.
 
@@ -102,26 +102,20 @@ def check_match(path_1, path_2):
     return True
 
 
-def gen_label(path_anno, path_names, path_out):
+def anno2label(path_anno, path_names, path_out):
     """
     Generate label txt from annotation.
 
     Args:
         path_anno: Path of the annotation file.
-        path_names: Path of the .names file.
+        path_names: Path of the .names file. Only the class in the .names will be converted.
         path_out: Path of the output .txt file.
 
     Returns:
         None
     """
     anno = parse_anno(path_anno)
-    name2label = {}
-    with open(path_names) as f:
-        label = 0
-        for l in f:
-            name = l.strip('\n')
-            name2label[name] = label
-            label += 1
+    name2label, _ = get_label(path_names)
 
     W, H = anno['size']['width'], anno['size']['height']
     row = []
@@ -144,7 +138,7 @@ def gen_label(path_anno, path_names, path_out):
         f.write('\n'.join(row))
 
 
-def gen_labels(path_anno_folder, path_names, path_out):
+def annos2labels(path_anno_folder, path_names, path_out):
     """
     Generate label txt from a list of annotations.
 
@@ -161,13 +155,13 @@ def gen_labels(path_anno_folder, path_names, path_out):
     path_names_ = [path_names for i in range(len(path_annos))]
     path_out_ = [path_out for i in range(len(path_annos))]
     pool = Pool(cpu_count())
-    pool.starmap(gen_label, zip(path_annos, path_names_,
-                                path_out_,))
+    pool.starmap(anno2label, zip(path_annos, path_names_,
+                                 path_out_,))
     pool.close()
     pool.join()
 
 
-def bbox_distribution(path_anno_folder, verbose=0):
+def bbox_dist(path_anno_folder, verbose=0):
     """
     Analysis the bbox distribution by a list of annotation files.
 
@@ -191,3 +185,26 @@ def bbox_distribution(path_anno_folder, verbose=0):
             print('{}: {}({:.4f}%)'.format(
                 name, d[name], 100*d[name]/d['LEN']))
     return d
+
+
+def get_label(path_names):
+    """
+    Get name2label and label2name from a .names file.
+
+    Args:
+        path_names: Path of the .names file.
+
+    Returns:
+        name2label: A dict like {'name1': 0, 'name2': 1, ...}
+        label2name: A dict like {0: 'name1', 1: 'name2', ...}
+    """
+    name2label = {}
+    label2name = {}
+    with open(path_names) as f:
+        label = 0
+        for l in f:
+            name = l.strip('\n')
+            name2label[name] = label
+            label2name[label] = name
+            label += 1
+    return name2label, label2name
